package DBIx::CheckConnectivity::Driver::Pg;

use warnings;
use strict;
use base qw/DBIx::CheckConnectivity::Driver/;

1;

__END__

=head1 NAME

DBIx::CheckConnectivity::Pg - 

=head1 INTERFACE

=over 4

=back

=head1 AUTHOR

sunnavy  C<< <sunnavy@bestpractical.com> >>


=head1 LICENCE AND COPYRIGHT

Copyright 2009 Best Practical Solutions.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

